==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/functions/import/12/setup.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
        $daten = fgetcsv($datei, 10000, ';');
        while ($daten)
        { 
          if ($daten[0]!='ID')
          { 
            if ( $daten[12]=='' )
            {
              echo '<span class="Fehlermeldung">ERROR: Setup UserMaximumInactivityTime is missing!</span><br />';
              echo "=> UserMaximumInactivityTime set to '10' minutes.<br />";
              $daten[12]='10';
            }
            $sql = "UPDATE ".$prefix."setup SET
              SetupRefreshtime = '$daten[1]',
              SetupRowsTextareas = '$daten[2]',
              SetupExportSeparator = '$daten[3]',
              SetupFrontendLanguage = '$daten[4]',
              SetupGuestbookEntriesPerPage = '$daten[5]',
              SetupGuestbookMail = '$daten[6]',
              SetupFrontendCssFile = '$daten[7]',
              SetupGuestbookEntriesUnlock = '$daten[8]',
              SetupGuestbookSpamDomains = '$daten[9]',
              SetupGuestbookSpamIPs = '$daten[10]',
              SetupGuestbookSpamWords = '$daten[11]',
              SetupUserMaximumInactivityTime = '$daten[12]',
              SetupNewsEntriesPerPage = '$daten[13]',
              SetupFrontendAllowOptionalGigs = '$daten[14]',
              SetupFrontendAllowPrivateGigs = '$daten[15]',
              SetupAllowDoubleDates = '$daten[16]',
              SetupCalendarAttributeInAddGigForm = '$daten[17]',
              SetupFrontendAttributes = '$daten[18]',
              SetupFrontendDetailAttributes = '$daten[19]',
              SetupNewsChannelTitle = '$daten[20]',
              SetupNewsChannelURL = '$daten[21]',
              SetupNewsChannelDescription = '$daten[22]',
              SetupNewsChannelLanguage = '$daten[23]',
              SetupNewsChannelCopyright = '$daten[24]',
              SetupFrontendCalendarCharsInFields = '$daten[25]',
              SetupFrontendCalendarShowTableHeads = '$daten[26]',
              SetupFrontendCalendarSelector = '$daten[27]',
              SetupFrontendCalendarMaxAmountOfGigs = '$daten[28]',
              SetupFrontendCalendarPeriodSelector = '$daten[29]',
              SetupFrontendCalendarShowMonthlySeparator = '$daten[30]',
              SetupShowEditorInAddGigForm = '$daten[31]'";
            $resultat = mysql_db_query($db_name, $sql);
            if ($resultat) { echo $L_Setup_successfully_imported.'<br />'; }
            else { echo '<span class="Fehlermeldung">'.$L_ERROR_Setup_NOT_imported.'</span><br />'; }
          }
        $daten = fgetcsv($datei, 10000, ';');
      }
?>

==> downloads.html?file=gigkalender_v1.2.63_076.zip: gigkalender/functions/import/12/setup.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
        $daten = fgetcsv($datei, 10000, ';');
        while ($daten)
        { 
          if ($daten[0]!='ID')
          { 
            if ( $daten[12]=='' )
            {
              echo '<span class="Fehlermeldung">ERROR: Setup UserMaximumInactivityTime is missing!</span><br />';
              echo "=> UserMaximumInactivityTime set to '10' minutes.<br />";
              $daten[12]='10';
            }
            $sql = "UPDATE ".$prefix."setup SET
              SetupRefreshtime = '$daten[1]',
              SetupRowsTextareas = '$daten[2]',
              SetupExportSeparator = '$daten[3]',
              SetupFrontendLanguage = '$daten[4]',
              SetupGuestbookEntriesPerPage = '$daten[5]',
              SetupGuestbookMail = '$daten[6]',
              SetupFrontendCssFile = '$daten[7]',
              SetupGuestbookEntriesUnlock = '$daten[8]',
              SetupGuestbookSpamDomains = '$daten[9]',
              SetupGuestbookSpamIPs = '$daten[10]',
              SetupGuestbookSpamWords = '$daten[11]',
              SetupUserMaximumInactivityTime = '$daten[12]',
              SetupNewsEntriesPerPage = '$daten[13]',
              SetupFrontendAllowOptionalGigs = '$daten[14]',
              SetupFrontendAllowPrivateGigs = '$daten[15]',
              SetupAllowDoubleDates = '$daten[16]',
              SetupCalendarAttributeInAddGigForm = '$daten[17]',
              SetupFrontendAttributes = '$daten[18]',
              SetupFrontendDetailAttributes = '$daten[19]',
              SetupNewsChannelTitle = '$daten[20]',
              SetupNewsChannelURL = '$daten[21]',
              SetupNewsChannelDescription = '$daten[22]',
              SetupNewsChannelLanguage = '$daten[23]',
              SetupNewsChannelCopyright = '$daten[24]',
              SetupFrontendCalendarCharsInFields = '$daten[25]',
              SetupFrontendCalendarShowTableHeads = '$daten[26]',
              SetupFrontendCalendarSelector = '$daten[27]',
              SetupFrontendCalendarMaxAmountOfGigs = '$daten[28]',
              SetupFrontendCalendarPeriodSelector = '$daten[29]',
              SetupFrontendCalendarShowMonthlySeparator = '$daten[30]',
              SetupShowEditorInAddGigForm = '1'";
            $resultat = mysql_db_query($db_name, $sql);
            if ($resultat) { echo $L_Setup_successfully_imported.'<br />'; }
            else { echo '<span class="Fehlermeldung">'.$L_ERROR_Setup_NOT_imported.'</span><br />'; }
          }
        $daten = fgetcsv($datei, 10000, ';');
      }
?>
